Global ('Self', nil );
Global ('SelfName', '');
Global ('Classes', { 'DRUID', 'MAGE', 'NECROMANCER', 'BARD', 'PALADIN', 'PRIEST', 'PSIONIC', 'STALKER',  'WARRIOR',  'ENGINEER' } );

Global ('MB_RIGHT', 1);
Global ('MB_LEFT', 0);

Global ('COLOR_BACKGROUND', { r = 0.0; g = 0.0; b = 0.0; a = 1.0 } );
Global ('COLOR_OFFLINE', { r = 0.2; g = 0.2; b = 0.2; a = 1.0 } );
Global ('COLOR_FAR', { r = 0.4; g = 0.4; b = 0.4; a = 1.0 } );
Global ('COLOR_UNKNOWN', { r = 1.0; g = 1.0; b = 1.0; a = 1.0 } );

Global ('COLOR_MANA', { r = 0.2; g = 0.2; b = 0.9; a = 1.0 } );
Global ('COLOR_ENERGY', { r = 0.9; g = 0.9; b = 0.2; a = 1.0 } );
Global ('COLOR_RC_NO', { r = 1; g = 0; b = 0; a = 1.0 }  );
Global ('COLOR_RC_OK', { r = 0; g = 1; b = 0; a = 1.0 }  );
Global ('COLOR_RC_UNK', { r = 0.1; g = 0.1; b = 0.1; a = 1.0 }  );

function UseSkill ( spell ) 
	local spellbook = avatar.GetSpellBook()
	for i, id in spellbook do
		--local spellInfo = avatar.GetSpellInfo( id )
		local spellInfo = spellLib.GetDescription( id )
		local name = WStringToString(spellInfo.name);
		if spell == name then
			avatar.RunSpell(id);
			return;
		end
	end
end

function ManaType2Color(id)
	if id == nil then
		return COLOR_UNKNOWN
	end
		
	local cls = unit.GetClass(id).manaType;
	if (cls == MANA_TYPE_MANA) then
		return COLOR_MANA
	else
		return COLOR_ENERGY;
	end
end

function UnitToClsColor(id)
	if id == nil then
		return COLOR_UNKNOWN
	end
		
	local cls = unit.GetClass(id).className;
	return Class2Color ( cls );
end

function sqr(x)
	return x * x;
end

function TableCount ( tbl )
	local count = 0;
	for k, v in tbl do
		count = count + 1;
	end
	
	return count;
end

function TableIndex ( tbl, val )
	local idx = 0;
	for k, v in tbl do
		if v == val then
			return idx;
		end
		idx = idx + 1;
	end
	
	return false;
end

function PosRange(a, b)	
	if (b == nil or a == nil) then
		return 9999;
	end
	
	return math.sqrt( sqr(b.posX - a.posX)  + sqr(b.posY - a.posY) + sqr(b.posZ - a.posZ));
end

function inTable(tbl, item)
    for key, value in pairs(tbl) do
        if value == item then return key end
    end
    return false
end

function inTableString(tbl, item)
	if item == '' then
		return false
	end
	
    for key, value in pairs(tbl) do
        if value ~= '' and value == item then return key end
    end
    return false
end

function inTablePartial(tbl, name)
	if name == '' then
		return false
	end
	
    for key, value in pairs(tbl) do
		if (value ~= '') then
			if string.find(name, value) then
				return key
			end
		end
    end
    return false
end

function GetCooldown (itemId) 
	local info = avatar.GetItemInfo( itemId );
	local spellInfo = avatar.GetSpellInfo( info.spellId )			
	return spellInfo.cooldownRemainingMs;
end

function Now()
	return common.GetLocalDateTime();
end

function TimeToStr(dt)
	return dt.h..':'..dt.min..':'..dt.s;
end

function WStringToString(WString)
	if (not WString) then return ""; end
	return userMods.FromWString(WString);
end

function GetCooldownString ( msec )
	local out = '';
	local count = SplitTime( msec );
	if count.hours > 1 then
		out =  WStringToString(common.FormatInt( math.ceil( count.hours ), "%d" ))..'h';
	elseif count.minutes > 1 then
		out = WStringToString(common.FormatInt( math.ceil( count.minutes ), "%d" ))..'m';
	else
		out =  WStringToString(common.FormatInt( Round( count.seconds ), "%d" ))..'s';
	end
	
	return out;
end

function StringToWString ( text ) 
	return userMods.ToWString(tostring(text));
end

function SetBackgroundTextureFromItem(widget, itemId )
	local resourceId = avatar.GetItemResourceId( itemId );
	local resourceInfo = avatar.GetItemResourceInfo( resourceId );
	local texture = resourceInfo.image;
	widget:SetBackgroundTexture(texture);
end

function SetButtonCaption ( widget, caption )
	widget:SetVal('button_label', userMods.ToWString(tostring(caption)));
end

function SetValue ( widget, caption )
	widget:SetVal('value', userMods.ToWString(tostring(caption)));
end

function GetItemCount( itemId )
	local info = avatar.GetItemInfo( itemId );
	return info.stackCount;
end

function GetUnitName(id)
	if (not id) then
		return "";
	end
	
	local wStr = object.GetName(id);
	return WStringToString(wStr);
end

function GetItemName ( itemId )
	local valuedObject = avatar.GetItemValuedObject( itemId );
	return WStringToString(valuedObject:GetText());
end

function InitAvatar()
	if Self then 
		return false;
	end 
	
	if not avatar.IsExist() then
		return false;
	end
	
	Self = avatar.GetId();
	SelfName = GetUnitName(Self);
	return true;
end
